@@ -3,6 +3,8 @@ package DBD::PO::db; # DATABASE
 use strict;
 use warnings;
 
+our $VERSION = '1.00';
+
 use DBD::File;
 use parent qw(-norequire DBD::File::db);
 
@@ -14,7 +16,7 @@ use SQL::Parser;
 use DBD::PO::Locale::PO;
 use DBD::PO::Text::PO qw($EOL_DEFAULT $SEPARATOR_DEFAULT $CHARSET_DEFAULT);
 
-our $imp_data_size = 0;
+our $imp_data_size = 0; ## no critic (PackageVars)
 
 my @header = (
     [ project_id_version        => 'Project-Id-Version: %s'        ],
@@ -120,6 +122,7 @@ sub quote {
            : "'$string'";
 }
 
+## no critic (MagicNumbers)
 my %hash2array = (
     'Project-Id-Version'        => 0,
     'POT-Creation-Date'         => 1,
@@ -134,10 +137,11 @@ my %hash2array = (
     'Content-Transfer-Encoding' => 7,
 );
 my $index_extended = 8;
+## use critic (MagicNumbers)
 
 my $valid_keys_regex = '(?xsm-i:\A (?: '
                        . join(
-                           '|',
+                           q{|},
                            map {
                                quotemeta $_
                            } keys %hash2array, 'extended'
@@ -145,15 +149,15 @@ my $valid_keys_regex = '(?xsm-i:\A (?: '
                        . ' ) \z)';
 
 sub _hash2array {
+    my ($hash_data, $charset) = @_;
     caller eq __PACKAGE__
         or croak 'Do not call a private sub';
-    my ($hash_data, $charset) = @_;
     validate_with(
         params => $hash_data,
         spec   => {
             (
                 map {
-                    ($_ => => {type => SCALAR, optional => 1});
+                    ($_ => {type => SCALAR, optional => 1});
                 } keys %hash2array
             ),
             extended => {type => ARRAYREF, optional => 1},
@@ -180,7 +184,7 @@ sub _hash2array {
     return $array_data;
 };
 
-sub build_header_msgstr {
+sub build_header_msgstr { ## no critic (ArgUnpacking)
     my ($dbh, $anything) = validate_pos(
         @_,
         {isa   => 'DBI::db'},
@@ -231,7 +235,7 @@ sub build_header_msgstr {
     return join "\n", @header;
 }
 
-sub split_header_msgstr {
+sub split_header_msgstr { ## no critic (ArgUnpacking)
     my ($dbh, $anything) = validate_pos(
         @_,
         {isa   => 'DBI::db'},
@@ -309,7 +313,7 @@ EOT
     return \@cols;
 }
 
-sub get_header_msgstr_data {
+sub get_header_msgstr_data { ## no critic (ArgUnpacking)
     my ($dbh, $anything, $key) = validate_pos(
         @_,
         {isa  => 'DBI::db'},
@@ -356,6 +360,26 @@ sub get_header_msgstr_data {
 
 __END__
 
+=head1 NAME
+
+DBD::PO::db - database class for DBD::PO
+
+$Id: db.pm 246 2008-10-03 14:02:05Z steffenw $
+
+$HeadURL: https://dbd-po.svn.sourceforge.net/svnroot/dbd-po/trunk/DBD-PO/lib/DBD/PO/db.pm $
+
+=head1 VERSION
+
+1.00
+
+=head1 SYNOPSIS
+
+do not use
+
+=head1 DESCRIPTION
+
+database class for DBD::PO
+
 =head1 SUBROUTINES/METHODS
 
 =head2 method maketext_to_gettext
@@ -368,4 +392,53 @@ __END__
 
 =head2 method get_header_msgstr_data
 
+=head1 DIAGNOSTICS
+
+none
+
+=head1 CONFIGURATION AND ENVIRONMENT
+
+none
+
+=head1 DEPENDENCIES
+
+parent
+
+Carp
+
+Storable
+
+L<DBD::File>
+
+L<Params::Validate>
+
+L<SQL::Statement>
+
+L<SQL::Parser>
+
+L<DBD::PO::Locale::PO>
+
+=head1 INCOMPATIBILITIES
+
+not known
+
+=head1 BUGS AND LIMITATIONS
+
+not known
+
+=head1 AUTHOR
+
+Steffen Winkler
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (c) 2008,
+Steffen Winkler
+C<< <steffenw at cpan.org> >>.
+All rights reserved.
+
+This module is free software;
+you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
 =cut
\ No newline at end of file
